==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3FluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageRegistryConfigStorageS3FluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<A>{
  public ImageRegistryConfigStorageS3FluentImpl() {
  }
  public ImageRegistryConfigStorageS3FluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance) {
    this.withBucket(instance.getBucket()); 
    this.withCloudFront(instance.getCloudFront()); 
    this.withEncrypt(instance.getEncrypt()); 
    this.withKeyID(instance.getKeyID()); 
    this.withRegion(instance.getRegion()); 
    this.withRegionEndpoint(instance.getRegionEndpoint()); 
    this.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String bucket;
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder cloudFront;
  private java.lang.Boolean encrypt;
  private java.lang.String keyID;
  private java.lang.String region;
  private java.lang.String regionEndpoint;
  private java.lang.Boolean virtualHostedStyle;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBucket() {
    return this.bucket;
  }
  public A withBucket(java.lang.String bucket) {
    this.bucket=bucket; return (A) this;
  }
  public java.lang.Boolean hasBucket() {
    return this.bucket != null;
  }
  
  /**
   * Method is deprecated. use withBucket instead.
   */
  @java.lang.Deprecated
  public A withNewBucket(java.lang.String arg0) {
    return (A)withBucket(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCloudFront instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront getCloudFront() {
    return this.cloudFront!=null?this.cloudFront.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront buildCloudFront() {
    return this.cloudFront!=null?this.cloudFront.build():null;
  }
  public A withCloudFront(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront cloudFront) {
    _visitables.get("cloudFront").remove(this.cloudFront);
    if (cloudFront!=null){ this.cloudFront= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(cloudFront); _visitables.get("cloudFront").add(this.cloudFront);} return (A) this;
  }
  public java.lang.Boolean hasCloudFront() {
    return this.cloudFront != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> withNewCloudFront() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3FluentImpl.CloudFrontNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> withNewCloudFrontLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3FluentImpl.CloudFrontNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editCloudFront() {
    return withNewCloudFrontLike(getCloudFront());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editOrNewCloudFront() {
    return withNewCloudFrontLike(getCloudFront() != null ? getCloudFront(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editOrNewCloudFrontLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
    return withNewCloudFrontLike(getCloudFront() != null ? getCloudFront(): item);
  }
  public java.lang.Boolean getEncrypt() {
    return this.encrypt;
  }
  public A withEncrypt(java.lang.Boolean encrypt) {
    this.encrypt=encrypt; return (A) this;
  }
  public java.lang.Boolean hasEncrypt() {
    return this.encrypt != null;
  }
  public java.lang.String getKeyID() {
    return this.keyID;
  }
  public A withKeyID(java.lang.String keyID) {
    this.keyID=keyID; return (A) this;
  }
  public java.lang.Boolean hasKeyID() {
    return this.keyID != null;
  }
  
  /**
   * Method is deprecated. use withKeyID instead.
   */
  @java.lang.Deprecated
  public A withNewKeyID(java.lang.String arg0) {
    return (A)withKeyID(new String(arg0));
  }
  public java.lang.String getRegion() {
    return this.region;
  }
  public A withRegion(java.lang.String region) {
    this.region=region; return (A) this;
  }
  public java.lang.Boolean hasRegion() {
    return this.region != null;
  }
  
  /**
   * Method is deprecated. use withRegion instead.
   */
  @java.lang.Deprecated
  public A withNewRegion(java.lang.String arg0) {
    return (A)withRegion(new String(arg0));
  }
  public java.lang.String getRegionEndpoint() {
    return this.regionEndpoint;
  }
  public A withRegionEndpoint(java.lang.String regionEndpoint) {
    this.regionEndpoint=regionEndpoint; return (A) this;
  }
  public java.lang.Boolean hasRegionEndpoint() {
    return this.regionEndpoint != null;
  }
  
  /**
   * Method is deprecated. use withRegionEndpoint instead.
   */
  @java.lang.Deprecated
  public A withNewRegionEndpoint(java.lang.String arg0) {
    return (A)withRegionEndpoint(new String(arg0));
  }
  public java.lang.Boolean getVirtualHostedStyle() {
    return this.virtualHostedStyle;
  }
  public A withVirtualHostedStyle(java.lang.Boolean virtualHostedStyle) {
    this.virtualHostedStyle=virtualHostedStyle; return (A) this;
  }
  public java.lang.Boolean hasVirtualHostedStyle() {
    return this.virtualHostedStyle != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageS3FluentImpl that = (ImageRegistryConfigStorageS3FluentImpl) o;
    if (bucket != null ? !bucket.equals(that.bucket) :that.bucket != null) return false;
    if (cloudFront != null ? !cloudFront.equals(that.cloudFront) :that.cloudFront != null) return false;
    if (encrypt != null ? !encrypt.equals(that.encrypt) :that.encrypt != null) return false;
    if (keyID != null ? !keyID.equals(that.keyID) :that.keyID != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (regionEndpoint != null ? !regionEndpoint.equals(that.regionEndpoint) :that.regionEndpoint != null) return false;
    if (virtualHostedStyle != null ? !virtualHostedStyle.equals(that.virtualHostedStyle) :that.virtualHostedStyle != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucket,  cloudFront,  encrypt,  keyID,  region,  regionEndpoint,  virtualHostedStyle,  additionalProperties,  super.hashCode());
  }
  public class CloudFrontNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CloudFrontNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(this, item);
    }
    CloudFrontNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigStorageS3FluentImpl.this.withCloudFront(builder.build());
    }
    public N endCloudFront() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageS3FluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageRegistryConfigStorageS3FluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent<A>{
  public ImageRegistryConfigStorageS3FluentImpl() {
  }
  public ImageRegistryConfigStorageS3FluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3 instance) {
    this.withBucket(instance.getBucket()); 
    this.withCloudFront(instance.getCloudFront()); 
    this.withEncrypt(instance.getEncrypt()); 
    this.withKeyID(instance.getKeyID()); 
    this.withRegion(instance.getRegion()); 
    this.withRegionEndpoint(instance.getRegionEndpoint()); 
    this.withVirtualHostedStyle(instance.getVirtualHostedStyle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String bucket;
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder cloudFront;
  private java.lang.Boolean encrypt;
  private java.lang.String keyID;
  private java.lang.String region;
  private java.lang.String regionEndpoint;
  private java.lang.Boolean virtualHostedStyle;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBucket() {
    return this.bucket;
  }
  public A withBucket(java.lang.String bucket) {
    this.bucket=bucket; return (A) this;
  }
  public java.lang.Boolean hasBucket() {
    return this.bucket != null;
  }
  
  /**
   * Method is deprecated. use withBucket instead.
   */
  @java.lang.Deprecated
  public A withNewBucket(java.lang.String arg0) {
    return (A)withBucket(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCloudFront instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront getCloudFront() {
    return this.cloudFront!=null?this.cloudFront.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront buildCloudFront() {
    return this.cloudFront!=null?this.cloudFront.build():null;
  }
  public A withCloudFront(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront cloudFront) {
    _visitables.get("cloudFront").remove(this.cloudFront);
    if (cloudFront!=null){ this.cloudFront= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(cloudFront); _visitables.get("cloudFront").add(this.cloudFront);} return (A) this;
  }
  public java.lang.Boolean hasCloudFront() {
    return this.cloudFront != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> withNewCloudFront() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3FluentImpl.CloudFrontNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> withNewCloudFrontLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3FluentImpl.CloudFrontNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editCloudFront() {
    return withNewCloudFrontLike(getCloudFront());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editOrNewCloudFront() {
    return withNewCloudFrontLike(getCloudFront() != null ? getCloudFront(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<A> editOrNewCloudFrontLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
    return withNewCloudFrontLike(getCloudFront() != null ? getCloudFront(): item);
  }
  public java.lang.Boolean getEncrypt() {
    return this.encrypt;
  }
  public A withEncrypt(java.lang.Boolean encrypt) {
    this.encrypt=encrypt; return (A) this;
  }
  public java.lang.Boolean hasEncrypt() {
    return this.encrypt != null;
  }
  public java.lang.String getKeyID() {
    return this.keyID;
  }
  public A withKeyID(java.lang.String keyID) {
    this.keyID=keyID; return (A) this;
  }
  public java.lang.Boolean hasKeyID() {
    return this.keyID != null;
  }
  
  /**
   * Method is deprecated. use withKeyID instead.
   */
  @java.lang.Deprecated
  public A withNewKeyID(java.lang.String arg0) {
    return (A)withKeyID(new String(arg0));
  }
  public java.lang.String getRegion() {
    return this.region;
  }
  public A withRegion(java.lang.String region) {
    this.region=region; return (A) this;
  }
  public java.lang.Boolean hasRegion() {
    return this.region != null;
  }
  
  /**
   * Method is deprecated. use withRegion instead.
   */
  @java.lang.Deprecated
  public A withNewRegion(java.lang.String arg0) {
    return (A)withRegion(new String(arg0));
  }
  public java.lang.String getRegionEndpoint() {
    return this.regionEndpoint;
  }
  public A withRegionEndpoint(java.lang.String regionEndpoint) {
    this.regionEndpoint=regionEndpoint; return (A) this;
  }
  public java.lang.Boolean hasRegionEndpoint() {
    return this.regionEndpoint != null;
  }
  
  /**
   * Method is deprecated. use withRegionEndpoint instead.
   */
  @java.lang.Deprecated
  public A withNewRegionEndpoint(java.lang.String arg0) {
    return (A)withRegionEndpoint(new String(arg0));
  }
  public java.lang.Boolean getVirtualHostedStyle() {
    return this.virtualHostedStyle;
  }
  public A withVirtualHostedStyle(java.lang.Boolean virtualHostedStyle) {
    this.virtualHostedStyle=virtualHostedStyle; return (A) this;
  }
  public java.lang.Boolean hasVirtualHostedStyle() {
    return this.virtualHostedStyle != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageS3FluentImpl that = (ImageRegistryConfigStorageS3FluentImpl) o;
    if (bucket != null ? !bucket.equals(that.bucket) :that.bucket != null) return false;
    if (cloudFront != null ? !cloudFront.equals(that.cloudFront) :that.cloudFront != null) return false;
    if (encrypt != null ? !encrypt.equals(that.encrypt) :that.encrypt != null) return false;
    if (keyID != null ? !keyID.equals(that.keyID) :that.keyID != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (regionEndpoint != null ? !regionEndpoint.equals(that.regionEndpoint) :that.regionEndpoint != null) return false;
    if (virtualHostedStyle != null ? !virtualHostedStyle.equals(that.virtualHostedStyle) :that.virtualHostedStyle != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucket,  cloudFront,  encrypt,  keyID,  region,  regionEndpoint,  virtualHostedStyle,  additionalProperties,  super.hashCode());
  }
  public class CloudFrontNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3Fluent.CloudFrontNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CloudFrontNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFront item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(this, item);
    }
    CloudFrontNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageS3CloudFrontBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigStorageS3FluentImpl.this.withCloudFront(builder.build());
    }
    public N endCloudFront() {
      return and();
    }
    
  }
  
}
